package testes.sialocacao.alocacao;

import sialocacao.*;
import sialocacao.disciplina.*;
import sialocacao.professor.*;
import sialocacao.sala.*;
import sialocacao.alocacao.*;
import sialocacao.util.*;
import sialocacao.timetabling.*;
import junit.framework.*;

import java.util.*;

public class AlocacaoTest extends TestCase{
  private SIAlocacao sia;

  public AlocacaoTest (String name){
    super(name);
    sia = new SIAlocacao();
  }

  public void testAssociarDisciplinaProfessor(){
    try{
      //inserir disciplina

      String descricaoDisciplina = "disciplina"+System.currentTimeMillis();
      int cargaHoraria = 30;
      String ementa = "ementa"+System.currentTimeMillis();

      List categorias =
        sia.listarCategorias();

      Map prioridades =
        new HashMap();

      for(int i=0; i<categorias.size(); i++) {
        String codCategoria = ((Categoria)categorias.get(i)).getCodigo()+"";

        String codPreferencia =
          String.valueOf(TimetablingGenetico.PREFERENCIA_ALTA);

        prioridades.put(codCategoria, codPreferencia);
      }

      sia.inserirDisciplina(descricaoDisciplina, cargaHoraria, ementa,
        prioridades);

      Disciplina disciplina =
        sia.buscarDisciplina(descricaoDisciplina);

      //inserir professor

      String nome =
        "professor"+System.currentTimeMillis();

      String cpf =
        String.valueOf(System.currentTimeMillis());

      sia.inserirProfessor(nome, cpf);

      Professor professor =
        sia.buscarProfessor(nome);

      //associa professor/disciplina

      sia.associaProfessorDisciplina(disciplina, professor.getCodigo());

      Assert.assertTrue(true);// sucesso
    } catch(Exception e){
        e.printStackTrace();
        Assert.assertTrue(false);// erro
      }
  }


  public void testAlocar(){
    try{
      //inserir disciplina

      String descricaoDisciplina = "disciplina"+System.currentTimeMillis();
      int cargaHoraria = 30;
      String ementa = "ementa"+System.currentTimeMillis();

      List categorias =
        sia.listarCategorias();

      Map prioridades =
        new HashMap();

      for(int i=0; i<categorias.size(); i++) {
        String codCategoria = ((Categoria)categorias.get(i)).getCodigo()+"";

        String codPreferencia =
          String.valueOf(TimetablingGenetico.PREFERENCIA_ALTA);

        prioridades.put(codCategoria, codPreferencia);
      }

      sia.inserirDisciplina(descricaoDisciplina, cargaHoraria, ementa,
        prioridades);

      Disciplina disciplina =
        sia.buscarDisciplina(descricaoDisciplina);

      //inserir sala
      String descricaoSala =
        "sala"+System.currentTimeMillis();

      String localizacao =
        "sala"+System.currentTimeMillis();

      String observacao =
        "sala"+System.currentTimeMillis();

      int categoria = 2;

      sia.inserirSala(descricaoSala, localizacao, observacao, categoria);

      Sala sala =
        sia.buscarSala(descricaoSala);

      //inserir professor

      String nome =
        "professor"+System.currentTimeMillis();

      String cpf =
        String.valueOf(System.currentTimeMillis());

      sia.inserirProfessor(nome, cpf);

      Professor professor =
        sia.buscarProfessor(nome);

     //alocar
     Horario horario =
       sia.buscarHorario(Horario.SEGUNDA, "08:00", "09:00");

      Date dat =
        new Date();

      Data data =
        new Data(dat.getDate(), dat.getMonth()+1, dat.getYear()+1900);

      sia.alocar(sala, disciplina, horario, professor, data);

      Assert.assertTrue(true);// sucesso
    } catch(Exception e){
        e.printStackTrace();
        Assert.assertTrue(false);// erro
      }
  }

  public void testAlterarAlocacao(){
    try{
      //inserir disciplina

      String descricaoDisciplina = "disciplina"+System.currentTimeMillis();
      int cargaHoraria = 30;
      String ementa = "ementa"+System.currentTimeMillis();

      List categorias =
        sia.listarCategorias();

      Map prioridades =
        new HashMap();

      for(int i=0; i<categorias.size(); i++) {
        String codCategoria = ((Categoria)categorias.get(i)).getCodigo()+"";

        String codPreferencia =
          String.valueOf(TimetablingGenetico.PREFERENCIA_ALTA);

        prioridades.put(codCategoria, codPreferencia);
      }

      sia.inserirDisciplina(descricaoDisciplina, cargaHoraria, ementa,
        prioridades);

      Disciplina disciplina =
        sia.buscarDisciplina(descricaoDisciplina);

      //inserir sala
      String descricaoSala =
        "sala"+System.currentTimeMillis();

      String localizacao =
        "sala"+System.currentTimeMillis();

      String observacao =
        "sala"+System.currentTimeMillis();

      int categoria = 2;

      sia.inserirSala(descricaoSala, localizacao, observacao, categoria);

      Sala sala =
        sia.buscarSala(descricaoSala);

      //inserir professor

      String nome =
        "professor"+System.currentTimeMillis();

      String cpf =
        String.valueOf(System.currentTimeMillis());

      sia.inserirProfessor(nome, cpf);

      Professor professor =
        sia.buscarProfessor(nome);

      //Buscar um Horario

      Horario horario =
        sia.buscarHorario(Horario.SEGUNDA, "08:00", "09:00");

      //alocar

      Date dat =
        new Date();

      Data data =
        new Data(dat.getDate(), dat.getMonth()+1, dat.getYear()+1900);

      sia.alocar(sala, disciplina, horario, professor, data);

      //buscar alocacao

      Alocacao alocacao =
        sia.getAlocacao(sala, horario, data);

      //alterar alocacao

      descricaoSala =
        "sala"+System.currentTimeMillis();

      localizacao =
        "sala"+System.currentTimeMillis();

      observacao =
        "sala"+System.currentTimeMillis();

      categoria = 2;

      sia.inserirSala(descricaoSala, localizacao, observacao, categoria);

      sala =
        sia.buscarSala(descricaoSala);

      alocacao.setCodSala(sala.getCodigo());

      sia.alterarAlocacao(alocacao);

      Assert.assertTrue(true);// sucesso
    } catch(Exception e){
        e.printStackTrace();
        Assert.assertTrue(false);// erro
      }
  }

  public void testConsultar(){
    try{
      //inserir disciplina

      String descricaoDisciplina = "disciplina"+System.currentTimeMillis();
      int cargaHoraria = 30;
      String ementa = "ementa"+System.currentTimeMillis();

      List categorias =
        sia.listarCategorias();

      Map prioridades =
        new HashMap();

      for(int i=0; i<categorias.size(); i++) {
        String codCategoria = ((Categoria)categorias.get(i)).getCodigo()+"";

        String codPreferencia =
          String.valueOf(TimetablingGenetico.PREFERENCIA_ALTA);

        prioridades.put(codCategoria, codPreferencia);
      }

      sia.inserirDisciplina(descricaoDisciplina, cargaHoraria, ementa,
        prioridades);

      Disciplina disciplina =
        sia.buscarDisciplina(descricaoDisciplina);

      //inserir sala
      String descricaoSala =
        "sala"+System.currentTimeMillis();

      String localizacao =
        "sala"+System.currentTimeMillis();

      String observacao =
        "sala"+System.currentTimeMillis();

      int categoria = 2;

      sia.inserirSala(descricaoSala, localizacao, observacao, categoria);

      Sala sala =
        sia.buscarSala(descricaoSala);

      //inserir professor

      String nome =
        "professor"+System.currentTimeMillis();

      String cpf =
        String.valueOf(System.currentTimeMillis());

      sia.inserirProfessor(nome, cpf);

      Professor professor =
        sia.buscarProfessor(nome);

      //Buscar um Horario

      Horario horario =
        sia.buscarHorario(Horario.SEGUNDA, "08:00", "09:00");

      //alocar

      Date dat =
        new Date();

      Data data =
        new Data(dat.getDate(), dat.getMonth()+1, dat.getYear()+1900);

      sia.alocar(sala, disciplina, horario, professor, data);

      //buscar alocacao

      Alocacao alocacao =
        sia.getAlocacao(sala, horario, data);

      Assert.assertTrue(true);// sucesso
    } catch(Exception e){
        e.printStackTrace();
        Assert.assertTrue(false);// erro
      }
  }
}